<?php
/*
Plugin Name: Fix Jumping Header Divi
Description: Install & enable plugin and say good bye to Divi theme header jumping issue.
Author: WP-EXPERTS.IN Team
Author URI: https://www.wp-experts.in
Version: 1.1
License GPL2
Copyright 2022  WP-Experts.IN  (email  raghunath.0087@gmail.com)

This program is free software; you can redistribute it andor modify
it under the terms of the GNU General Public License, version 2, as 
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
if(!class_exists('FixJumpingHeaderDivi'))
{
    class FixJumpingHeaderDivi {
        /**
         * Construct the plugin object
         */
        public function __construct() {
			// Installation and uninstallation hooks
			register_activation_hook( __FILE__,  array(&$this, 'fjhd_activate') );
			register_deactivation_hook( __FILE__,  array(&$this, 'fjhd_deactivate') );
			// admin settings links
			add_filter( "plugin_action_links_".plugin_basename(__FILE__), array(&$this,'fjhd_settings_link') );
            // register actions
			add_action( 'admin_init', array( &$this, 'fjhd_admin_init') );
			add_action( 'admin_menu', array( &$this, 'fjhd_add_menu') );
            add_action( 'admin_bar_menu', array( &$this, 'toolbar_link_to_fjhd'), 999 );
            add_action( 'wp_enqueue_scripts', array( &$this, 'fjhd_enqueue_scripts_hooks') );
			add_action( 'wp_ajax_fjhd_ajax_hooks', array( &$this, 'fjhd_ajax_hooks') );
			
        } // END public function __construct
		/**
		 * hook to add link under adminmenu bar
		 */		
		public function toolbar_link_to_fjhd( $wp_admin_bar ) {
			$args = array(
				'id'    => 'fjhd_menu_bar',
				'title' => 'Divi Header Jump',
				'href'  => admin_url('themes.php?page=fjhd_settingsi'),
				'meta'  => array( 'class' => 'fjhd-toolbar-page' )
			);
			$wp_admin_bar->add_node( $args );
			//second lavel
			$wp_admin_bar->add_node( array(
				'id'    => 'fjhd-second-sub-item',
				'parent' => 'fjhd_menu_bar',
				'title' => 'Settings',
				'href'  => admin_url('themes.php?page=fjhd_settings'),
				'meta'  => array(
					'title' => __('Settings'),
					'target' => '_self',
					'class' => 'fjhd_menu_item_class'
				),
			));
		}
	

		/**
		* Manage enqueue script hooks
		*/
		public function fjhd_enqueue_scripts_hooks(){	
		    
	
		$isActive = get_option('fjhd_enable',0);
		
		 if (!current_user_can('administrator')) {
			return;
		}		 
		//check active or not
		if ( !$isActive ) {
			return;
		}
					
			 // set cookie based CSS		
			  $cookiecss = '';
			 if(isset($_COOKIE['divi-ptop'])) {
    
               $cookiecss .= ' #page-container {padding-top: '.$_COOKIE['divi-ptop'].' !important;} ';
            }
            
            if(isset($_COOKIE['divi-top'])) {
                
               $cookiecss .= ' #main-header {top: '.$_COOKIE['divi-top'].' !important;} ';
               
            }
			 // register css  
			 wp_register_style( 'fjhd-style', false );
			 wp_enqueue_style( 'fjhd-style' );
			 wp_add_inline_style( 'fjhd-style', $cookiecss );
			 
    	//control through cookie
		$cookiejs = '
		jQuery(document).ready(function() {
		jQuery(window).load(function() {
        setTimeout(function() { 
            
             var ptop = document.getElementById("page-container").style.paddingTop;
             var top = document.getElementById("main-header").style.top;
             
             document.cookie = "divi-ptop="+ptop+"; expires=Session; path=/";
             document.cookie = "divi-top="+top+"; expires=Session; path=/";
        
        }, 1000);
        }) 
         }) ;
		   ';
		   
			wp_add_inline_script( 'jquery-core', $cookiejs );
		
		}
		
		/**
		 * hook into WP's admin_init action hook
		 */
		public function fjhd_admin_init() {
			// Set up the settings for this plugin
			$this->fjhd_init_settings();
			// Possibly do additional admin_init tasks
		} // END public static function activate
		/**
		 * Initialize some custom settings
		 */     
		public function fjhd_init_settings() {
			// register the settings for this plugin
			register_setting('fjhd-group', 'fjhd_enable', 'sanitize_text_field');
		} // END public function init_custom_settings()
		/**
		 * add a menu
		 */     
		public function fjhd_add_menu()	{
			add_submenu_page(
			'themes.php',
			__( 'Header Jump Issue', 'wpexpertsin' ),
			__( 'Header Jump Issue', 'wpexpertsin' ),
			'manage_options',
			'fjhd_settings', 
			array(&$this, 'fjhd_settings_page'), 50 
		);
		} // END public function add_menu()

		/**
		 * Menu Callback
		 */     
		public function fjhd_settings_page() {
			if( !current_user_can('manage_options') ) 	{
				wp_die(__('You do not have sufficient permissions to access this page.'));
			}

			// Render the settings template
			include(sprintf("%s/lib/settings.php", dirname(__FILE__)));
			//include(sprintf("%s/css/admin.css", dirname(__FILE__)));
			// Style Files
			wp_register_style( 'fjhd_admin_style', plugins_url( 'css/fjhd-admin.css',__FILE__ ) );
			wp_enqueue_style( 'fjhd_admin_style' );
			// JS files
			wp_register_script('fjhd_admin_script', plugins_url('/js/fjhd-admin.js',__FILE__ ), array('jquery'));
            wp_enqueue_script('fjhd_admin_script');
		} // END public function plugin_settings_page()
        /**
         * Activate the plugin
         */
        public function fjhd_activate() {
            // Check current theme is Divi or not
			$theme = wp_get_theme(); // gets the current theme
			if ( 'Divi' == $theme->name || 'Divi' == $theme->parent_theme ) {
				// if you're here Twenty Twelve is the active theme or is
				// the current theme's parent theme
			}else {
				$error_message = __('This plugin requires <a href="https://www.elegantthemes.com/gallery/divi/" target="_blank">Divi</a> theme to be active!', 'fjhd');
				die($error_message);
			}
        } // END public static function activate
    
        /**
         * Deactivate the plugin
         */     
        public function fjhd_deactivate() {
            // Do nothing
        } // END public static function deactivate
        // Add the settings link to the plugins page
		public function fjhd_settings_link($links) { 
			$settings_link = '<a href="themes.php?page=fjhd_settings">Settings</a>'; 
			array_unshift($links, $settings_link); 
			return $links; 
		}
    } // END class FixJumpingHeaderDivi
} // END if(!class_exists('FixJumpingHeaderDivi'))

if( class_exists( 'FixJumpingHeaderDivi' ) ) {
    // instantiate the plugin class
    $initPlugin = new FixJumpingHeaderDivi();
}
